@@ -11,7 +11,7 @@ import json
 
 class Background:
     def __init__(self,objname='None',gfile='None',tfile='None',extnum=1,
-                 padxleft=5,xleft=100,xright=200,padxright=5,
+                 padxleft=5,padxright=5,
                  padyup=5,halfdy=5,padylow=5,
                  adjustx=0,adjusty=0
                 ):
@@ -23,7 +23,7 @@ class Background:
                     }
         self.data['ROOTNAME'] = self._rootname()
         self.trace = self._trace()
-        self.bbox = {'padxleft':padxleft,'xleft':xleft,'xright':xright,'padxright':padxright,
+        self.bbox = {'padxleft':padxleft,'padxright':padxright,
                      'padyup':padyup,'halfdy':halfdy,'padylow':padylow,
                      'adjustx':adjustx,'adjusty':adjusty,
                      'bbox':None
